@@ -1,18 +1,17 @@
-import sys, os
+import sys
 
-APP_DIR = os.path.dirname(os.path.abspath(__file__))
-PROJECT_DIR = os.path.dirname(APP_DIR)
+#  Note: need to import from package when running from wheel.
+# if running locally through main.py file, these imports should be replaced
+#       from . import settings, from . import services, from . import files
+# annoying, but it is what it is.
+if __name__=="__main__":
+    import settings, services, files
 
-sys.path.append(APP_DIR)
-
-import settings
-import services
-import files
-
-import analysis.statistics as statistics
-import analysis.optimizer as optimizer
-import analysis.markets as markets
+else:
+    from scrilla import settings, services, files
 
+from util import helper, outputter, formatter
+from analysis import statistics, optimizer, markets
 from objects.portfolio import Portfolio
 from objects.cashflow import Cashflow
 
@@ -21,10 +20,6 @@ if settings.APP_ENV != "container":
     import gui.menu as menu
     import util.plotter as plotter
 
-import util.helper as helper
-import util.outputter as outputter
-import util.formatter as formatter
-
 logger = outputter.Logger('main', settings.LOG_LEVEL)
 
 """
@@ -89,7 +84,7 @@ def do_program():
             widget.resize(settings.GUI_WIDTH, settings.GUI_HEIGHT)
             widget.show()
 
-            sys.exit( exec_())
+            sys.exit(app.exec_())
 
         # NOTE: Docker doesn't support windowing libraries
         elif opt == formatter.FUNC_ARG_DICT["gui"] and settings.APP_ENV == "container":
