@@ -116,6 +116,9 @@ CACHE_PRICE_KEY="prices"
 CACHE_COR_KEY="correlation"
 CACHE_DIV_KEY="dividends"
 CACHE_STAT_KEY="statistic"
+CACHE_EQUITY_KEY="equity_statistic"
+
+print(CACHE_DIR)
 
 STATIC_DIR = os.path.join(APP_DIR, 'data', 'static')
 
